==> general_lib-0.0.28.tar.gz: lib/dart/pub.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names

import 'package:universal_io/io.dart';
import "package:path/path.dart" as path;

class Pub {
  Directory get base_directory {
    String? configDir;
    if (Platform.isLinux) {
      configDir = path.join(
          Platform.environment['XDG_CONFIG_HOME'] ??
              Platform.environment['HOME']!,
          '.pub-cache');
    } else if (Platform.isWindows) {
      configDir = Platform.environment['APPDATA']!;
    } else if (Platform.isMacOS) {
      configDir = path.join(
          Platform.environment['HOME']!, 'Library', 'Application Support');
    } else {
      configDir = path.join(Platform.environment['HOME'] ?? '', '.pub-cache');
    }
    return Directory(configDir);
  }

  Directory get bin_directory {
    return Directory(path.join(base_directory.path, "bin"));
  }

  Directory get git_directory {
    return Directory(path.join(base_directory.path, "git"));
  }

  Directory get global_packages_directory {
    return Directory(path.join(base_directory.path, "global_packages"));
  }

  Directory get hosted_directory {
    return Directory(path.join(base_directory.path, "hosted"));
  }

  Directory get hosted_hashes_directory {
    return Directory(path.join(base_directory.path, "hosted-hashes"));
  }

  Directory get temp_directory {
    return Directory(path.join(base_directory.path, "_temp"));
  }
}

==> general_lib-0.0.32.tar.gz: lib/dart/pub.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names

import 'package:universal_io/io.dart';
import "package:path/path.dart" as path;

class Pub {
  Directory get base_directory {
    String? configDir;
    if (Platform.isLinux) {
      configDir = path.join(Platform.environment['XDG_CONFIG_HOME'] ?? Platform.environment['HOME']!, '.pub-cache');
    } else if (Platform.isWindows) {
      configDir = Platform.environment['APPDATA']!;
    } else if (Platform.isMacOS) {
      configDir = path.join(Platform.environment['HOME']!, 'Library', 'Application Support');
    } else {
      configDir = path.join(Platform.environment['HOME'] ?? '', '.pub-cache');
    }
    return Directory(configDir);
  }

  Directory get bin_directory {
    return Directory(path.join(base_directory.path, "bin"));
  }

  Directory get git_directory {
    return Directory(path.join(base_directory.path, "git"));
  }

  Directory get global_packages_directory {
    return Directory(path.join(base_directory.path, "global_packages"));
  }

  Directory get hosted_directory {
    return Directory(path.join(base_directory.path, "hosted"));
  }

  Directory get hosted_hashes_directory {
    return Directory(path.join(base_directory.path, "hosted-hashes"));
  }

  Directory get temp_directory {
    return Directory(path.join(base_directory.path, "_temp"));
  }
}
